# coding: utf-8

"""
    Mantium API

    Mantium API Documentation  # noqa: E501

    The version of the OpenAPI document: 1.0.1089
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from mantium_spec.configuration import Configuration


class Moderation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'hate_speech': 'ModerationLevel',
        'self_harm': 'ModerationLevel',
        'sexual_content': 'ModerationLevel',
        'violence': 'ModerationLevel'
    }

    attribute_map = {
        'hate_speech': 'hate_speech',
        'self_harm': 'self_harm',
        'sexual_content': 'sexual_content',
        'violence': 'violence'
    }

    def __init__(self, hate_speech=None, self_harm=None, sexual_content=None, violence=None, local_vars_configuration=None):  # noqa: E501
        """Moderation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._hate_speech = None
        self._self_harm = None
        self._sexual_content = None
        self._violence = None
        self.discriminator = None

        if hate_speech is not None:
            self.hate_speech = hate_speech
        if self_harm is not None:
            self.self_harm = self_harm
        if sexual_content is not None:
            self.sexual_content = sexual_content
        if violence is not None:
            self.violence = violence

    @property
    def hate_speech(self):
        """Gets the hate_speech of this Moderation.  # noqa: E501


        :return: The hate_speech of this Moderation.  # noqa: E501
        :rtype: ModerationLevel
        """
        return self._hate_speech

    @hate_speech.setter
    def hate_speech(self, hate_speech):
        """Sets the hate_speech of this Moderation.


        :param hate_speech: The hate_speech of this Moderation.  # noqa: E501
        :type hate_speech: ModerationLevel
        """

        self._hate_speech = hate_speech

    @property
    def self_harm(self):
        """Gets the self_harm of this Moderation.  # noqa: E501


        :return: The self_harm of this Moderation.  # noqa: E501
        :rtype: ModerationLevel
        """
        return self._self_harm

    @self_harm.setter
    def self_harm(self, self_harm):
        """Sets the self_harm of this Moderation.


        :param self_harm: The self_harm of this Moderation.  # noqa: E501
        :type self_harm: ModerationLevel
        """

        self._self_harm = self_harm

    @property
    def sexual_content(self):
        """Gets the sexual_content of this Moderation.  # noqa: E501


        :return: The sexual_content of this Moderation.  # noqa: E501
        :rtype: ModerationLevel
        """
        return self._sexual_content

    @sexual_content.setter
    def sexual_content(self, sexual_content):
        """Sets the sexual_content of this Moderation.


        :param sexual_content: The sexual_content of this Moderation.  # noqa: E501
        :type sexual_content: ModerationLevel
        """

        self._sexual_content = sexual_content

    @property
    def violence(self):
        """Gets the violence of this Moderation.  # noqa: E501


        :return: The violence of this Moderation.  # noqa: E501
        :rtype: ModerationLevel
        """
        return self._violence

    @violence.setter
    def violence(self, violence):
        """Sets the violence of this Moderation.


        :param violence: The violence of this Moderation.  # noqa: E501
        :type violence: ModerationLevel
        """

        self._violence = violence

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Moderation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Moderation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Mantium API

    Mantium API Documentation  # noqa: E501

    The version of the OpenAPI document: 1.0.1089
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from mantium_spec.api.applications_api import ApplicationsApi

# import ApiClient
from mantium_spec.api_client import ApiClient
from mantium_spec.configuration import Configuration
from mantium_spec.exceptions import OpenApiException
from mantium_spec.exceptions import ApiTypeError
from mantium_spec.exceptions import ApiValueError
from mantium_spec.exceptions import ApiKeyError
from mantium_spec.exceptions import ApiAttributeError
from mantium_spec.exceptions import ApiException
# import models into sdk package
from mantium_spec.models.api_data_source_type import APIDataSourceType
from mantium_spec.models.answer import Answer
from mantium_spec.models.answer_meta import AnswerMeta
from mantium_spec.models.application_chat_response import ApplicationChatResponse
from mantium_spec.models.application_credential import ApplicationCredential
from mantium_spec.models.application_detail_response import ApplicationDetailResponse
from mantium_spec.models.application_query_request import ApplicationQueryRequest
from mantium_spec.models.application_query_response import ApplicationQueryResponse
from mantium_spec.models.application_response import ApplicationResponse
from mantium_spec.models.application_status import ApplicationStatus
from mantium_spec.models.application_top_k_query_request import ApplicationTopKQueryRequest
from mantium_spec.models.chat_answer import ChatAnswer
from mantium_spec.models.chat_config import ChatConfig
from mantium_spec.models.chat_gpt_plugin_application_detail_response import ChatGPTPluginApplicationDetailResponse
from mantium_spec.models.citation import Citation
from mantium_spec.models.content_creation_template_options import ContentCreationTemplateOptions
from mantium_spec.models.content_type import ContentType
from mantium_spec.models.credential_type import CredentialType
from mantium_spec.models.cursor_datamodel_page_application_response import CursorDatamodelPageApplicationResponse
from mantium_spec.models.custom_template_options import CustomTemplateOptions
from mantium_spec.models.customer_support_template_options import CustomerSupportTemplateOptions
from mantium_spec.models.data_source_type import DataSourceType
from mantium_spec.models.data_sources_inner import DataSourcesInner
from mantium_spec.models.document import Document
from mantium_spec.models.document_metadata import DocumentMetadata
from mantium_spec.models.event_planning_template_options import EventPlanningTemplateOptions
from mantium_spec.models.gitlab_data_source_details import GitlabDataSourceDetails
from mantium_spec.models.gitlab_project_info import GitlabProjectInfo
from mantium_spec.models.http_validation_error import HTTPValidationError
from mantium_spec.models.legal_documents_template_options import LegalDocumentsTemplateOptions
from mantium_spec.models.location_inner import LocationInner
from mantium_spec.models.mantium_retriever_tool import MantiumRetrieverTool
from mantium_spec.models.mantium_retriever_tool_config import MantiumRetrieverToolConfig
from mantium_spec.models.meeting_info_template_options import MeetingInfoTemplateOptions
from mantium_spec.models.moderation import Moderation
from mantium_spec.models.moderation_config import ModerationConfig
from mantium_spec.models.moderation_level import ModerationLevel
from mantium_spec.models.personal_knowledge_management_template_options import PersonalKnowledgeManagementTemplateOptions
from mantium_spec.models.product_documentation_template_options import ProductDocumentationTemplateOptions
from mantium_spec.models.recipe_management_template_options import RecipeManagementTemplateOptions
from mantium_spec.models.response_get_application_detail import ResponseGetApplicationDetail
from mantium_spec.models.shopify_template_options import ShopifyTemplateOptions
from mantium_spec.models.span import Span
from mantium_spec.models.template import Template
from mantium_spec.models.tools import Tools
from mantium_spec.models.tools_config import ToolsConfig
from mantium_spec.models.validation_error import ValidationError




# coding: utf-8

"""
    Mantium API

    Mantium API Documentation  # noqa: E501

    The version of the OpenAPI document: 1.0.1089
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from mantium_spec.configuration import Configuration


class Template(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'is_activating': 'bool',
        'api_data_source_details': 'list[GitlabDataSourceDetails]',
        'credentials': 'list[ApplicationCredential]',
        'dataset_id': 'str',
        'content_column': 'str',
        'embedding_column': 'str'
    }

    attribute_map = {
        'type': 'type',
        'is_activating': 'is_activating',
        'api_data_source_details': 'api_data_source_details',
        'credentials': 'credentials',
        'dataset_id': 'dataset_id',
        'content_column': 'content_column',
        'embedding_column': 'embedding_column'
    }

    def __init__(self, type='shopify', is_activating=False, api_data_source_details=None, credentials=None, dataset_id=None, content_column=None, embedding_column=None, local_vars_configuration=None):  # noqa: E501
        """Template - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._is_activating = None
        self._api_data_source_details = None
        self._credentials = None
        self._dataset_id = None
        self._content_column = None
        self._embedding_column = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if is_activating is not None:
            self.is_activating = is_activating
        if api_data_source_details is not None:
            self.api_data_source_details = api_data_source_details
        if credentials is not None:
            self.credentials = credentials
        self.dataset_id = dataset_id
        if content_column is not None:
            self.content_column = content_column
        if embedding_column is not None:
            self.embedding_column = embedding_column

    @property
    def type(self):
        """Gets the type of this Template.  # noqa: E501


        :return: The type of this Template.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Template.


        :param type: The type of this Template.  # noqa: E501
        :type type: str
        """
        allowed_values = ["shopify"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def is_activating(self):
        """Gets the is_activating of this Template.  # noqa: E501


        :return: The is_activating of this Template.  # noqa: E501
        :rtype: bool
        """
        return self._is_activating

    @is_activating.setter
    def is_activating(self, is_activating):
        """Sets the is_activating of this Template.


        :param is_activating: The is_activating of this Template.  # noqa: E501
        :type is_activating: bool
        """

        self._is_activating = is_activating

    @property
    def api_data_source_details(self):
        """Gets the api_data_source_details of this Template.  # noqa: E501


        :return: The api_data_source_details of this Template.  # noqa: E501
        :rtype: list[GitlabDataSourceDetails]
        """
        return self._api_data_source_details

    @api_data_source_details.setter
    def api_data_source_details(self, api_data_source_details):
        """Sets the api_data_source_details of this Template.


        :param api_data_source_details: The api_data_source_details of this Template.  # noqa: E501
        :type api_data_source_details: list[GitlabDataSourceDetails]
        """

        self._api_data_source_details = api_data_source_details

    @property
    def credentials(self):
        """Gets the credentials of this Template.  # noqa: E501


        :return: The credentials of this Template.  # noqa: E501
        :rtype: list[ApplicationCredential]
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        """Sets the credentials of this Template.


        :param credentials: The credentials of this Template.  # noqa: E501
        :type credentials: list[ApplicationCredential]
        """

        self._credentials = credentials

    @property
    def dataset_id(self):
        """Gets the dataset_id of this Template.  # noqa: E501

        ID of the input dataset  # noqa: E501

        :return: The dataset_id of this Template.  # noqa: E501
        :rtype: str
        """
        return self._dataset_id

    @dataset_id.setter
    def dataset_id(self, dataset_id):
        """Sets the dataset_id of this Template.

        ID of the input dataset  # noqa: E501

        :param dataset_id: The dataset_id of this Template.  # noqa: E501
        :type dataset_id: str
        """
        if self.local_vars_configuration.client_side_validation and dataset_id is None:  # noqa: E501
            raise ValueError("Invalid value for `dataset_id`, must not be `None`")  # noqa: E501

        self._dataset_id = dataset_id

    @property
    def content_column(self):
        """Gets the content_column of this Template.  # noqa: E501


        :return: The content_column of this Template.  # noqa: E501
        :rtype: str
        """
        return self._content_column

    @content_column.setter
    def content_column(self, content_column):
        """Sets the content_column of this Template.


        :param content_column: The content_column of this Template.  # noqa: E501
        :type content_column: str
        """

        self._content_column = content_column

    @property
    def embedding_column(self):
        """Gets the embedding_column of this Template.  # noqa: E501


        :return: The embedding_column of this Template.  # noqa: E501
        :rtype: str
        """
        return self._embedding_column

    @embedding_column.setter
    def embedding_column(self, embedding_column):
        """Sets the embedding_column of this Template.


        :param embedding_column: The embedding_column of this Template.  # noqa: E501
        :type embedding_column: str
        """

        self._embedding_column = embedding_column

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Template):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Template):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mantium API

    Mantium API Documentation  # noqa: E501

    The version of the OpenAPI document: 1.0.1089
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from mantium_spec.configuration import Configuration


class Answer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'answer': 'str',
        'score': 'float',
        'context': 'str',
        'offsets_in_document': 'list[Span]',
        'offsets_in_context': 'list[Span]',
        'meta': 'AnswerMeta'
    }

    attribute_map = {
        'answer': 'answer',
        'score': 'score',
        'context': 'context',
        'offsets_in_document': 'offsets_in_document',
        'offsets_in_context': 'offsets_in_context',
        'meta': 'meta'
    }

    def __init__(self, answer=None, score=None, context=None, offsets_in_document=None, offsets_in_context=None, meta=None, local_vars_configuration=None):  # noqa: E501
        """Answer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._answer = None
        self._score = None
        self._context = None
        self._offsets_in_document = None
        self._offsets_in_context = None
        self._meta = None
        self.discriminator = None

        self.answer = answer
        self.score = score
        self.context = context
        self.offsets_in_document = offsets_in_document
        self.offsets_in_context = offsets_in_context
        self.meta = meta

    @property
    def answer(self):
        """Gets the answer of this Answer.  # noqa: E501


        :return: The answer of this Answer.  # noqa: E501
        :rtype: str
        """
        return self._answer

    @answer.setter
    def answer(self, answer):
        """Sets the answer of this Answer.


        :param answer: The answer of this Answer.  # noqa: E501
        :type answer: str
        """
        if self.local_vars_configuration.client_side_validation and answer is None:  # noqa: E501
            raise ValueError("Invalid value for `answer`, must not be `None`")  # noqa: E501

        self._answer = answer

    @property
    def score(self):
        """Gets the score of this Answer.  # noqa: E501


        :return: The score of this Answer.  # noqa: E501
        :rtype: float
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this Answer.


        :param score: The score of this Answer.  # noqa: E501
        :type score: float
        """
        if self.local_vars_configuration.client_side_validation and score is None:  # noqa: E501
            raise ValueError("Invalid value for `score`, must not be `None`")  # noqa: E501

        self._score = score

    @property
    def context(self):
        """Gets the context of this Answer.  # noqa: E501


        :return: The context of this Answer.  # noqa: E501
        :rtype: str
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this Answer.


        :param context: The context of this Answer.  # noqa: E501
        :type context: str
        """
        if self.local_vars_configuration.client_side_validation and context is None:  # noqa: E501
            raise ValueError("Invalid value for `context`, must not be `None`")  # noqa: E501

        self._context = context

    @property
    def offsets_in_document(self):
        """Gets the offsets_in_document of this Answer.  # noqa: E501


        :return: The offsets_in_document of this Answer.  # noqa: E501
        :rtype: list[Span]
        """
        return self._offsets_in_document

    @offsets_in_document.setter
    def offsets_in_document(self, offsets_in_document):
        """Sets the offsets_in_document of this Answer.


        :param offsets_in_document: The offsets_in_document of this Answer.  # noqa: E501
        :type offsets_in_document: list[Span]
        """
        if self.local_vars_configuration.client_side_validation and offsets_in_document is None:  # noqa: E501
            raise ValueError("Invalid value for `offsets_in_document`, must not be `None`")  # noqa: E501

        self._offsets_in_document = offsets_in_document

    @property
    def offsets_in_context(self):
        """Gets the offsets_in_context of this Answer.  # noqa: E501


        :return: The offsets_in_context of this Answer.  # noqa: E501
        :rtype: list[Span]
        """
        return self._offsets_in_context

    @offsets_in_context.setter
    def offsets_in_context(self, offsets_in_context):
        """Sets the offsets_in_context of this Answer.


        :param offsets_in_context: The offsets_in_context of this Answer.  # noqa: E501
        :type offsets_in_context: list[Span]
        """
        if self.local_vars_configuration.client_side_validation and offsets_in_context is None:  # noqa: E501
            raise ValueError("Invalid value for `offsets_in_context`, must not be `None`")  # noqa: E501

        self._offsets_in_context = offsets_in_context

    @property
    def meta(self):
        """Gets the meta of this Answer.  # noqa: E501


        :return: The meta of this Answer.  # noqa: E501
        :rtype: AnswerMeta
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """Sets the meta of this Answer.


        :param meta: The meta of this Answer.  # noqa: E501
        :type meta: AnswerMeta
        """
        if self.local_vars_configuration.client_side_validation and meta is None:  # noqa: E501
            raise ValueError("Invalid value for `meta`, must not be `None`")  # noqa: E501

        self._meta = meta

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Answer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Answer):
            return True

        return self.to_dict() != other.to_dict()
